futility/updater: update smm store filename to use an underscore

Rename "smm store" to "smm_store".

Depends on CL:1351857.

BUG=b:120060878
TEST=None

Change-Id: Iae511ecdc6d918d06218de1b651b1e5e3821d2f1
Reviewed-on: https://chromium-review.googlesource.com/1351178
Commit-Ready: ChromeOS CL Exonerator Bot <chromiumos-cl-exonerator@appspot.gserviceaccount.com>
Tested-by: Joel Kitching <kitching@chromium.org>
Reviewed-by: Hung-Te Lin <hungte@chromium.org>
diff --git a/futility/updater_quirks.c b/futility/updater_quirks.c
index 6d51072..9c27959 100644
--- a/futility/updater_quirks.c
+++ b/futility/updater_quirks.c
@@ -263,16 +263,16 @@
 
 /*
  * Quirk to help preserving SMM store on devices without a dedicated "SMMSTORE"
  * FMAP section. These devices will store "smm store" file in same CBFS where
  * the legacy boot loader lives (i.e, FMAP RW_LEGACY).
  * Note this currently has dependency on external program "cbstool".
  * Returns 0 if the SMM store is properly preserved, or if the system is not
  * available to do that (problem in cbfstool, or no "smm store" in current
  * system firmware). Otherwise non-zero as failure.
  */
 static int quirk_eve_smm_store(struct updater_config *cfg)
 {
-	const char *smm_store_name = "smm store";
+	const char *smm_store_name = "smm_store";
 	const char *temp_image = updater_create_temp_file(cfg);
 	const char *old_store;
 	char *command;
@@ -263,16 +263,16 @@
 /*
  * Quirk to help preserving SMM store on devices without a dedicated "SMMSTORE"
- * FMAP section. These devices will store "smm store" file in same CBFS where
+ * FMAP section. These devices will store "smm_store" file in same CBFS where
  * the legacy boot loader lives (i.e, FMAP RW_LEGACY).
  * Note this currently has dependency on external program "cbstool".
@@ -263,16 +263,16 @@
  * Note this currently has dependency on external program "cbstool".
  * Returns 0 if the SMM store is properly preserved, or if the system is not
- * available to do that (problem in cbfstool, or no "smm store" in current
+ * available to do that (problem in cbfstool, or no "smm_store" in current
  * system firmware). Otherwise non-zero as failure.
  */